#include "StdAfx.h"
#include "Lander.h"

Lander::Lander(void)
{
    rotation=0;
    rotationSpeed=2;
	
	gravity=-0.02;
	rotationSpeed=1.5;
	engine_acceleration=Vector(0.0,0.2);
	pos=Vector(400.0,300.0);
	vel=Vector(0.0,0.0);
	
    flame=false;
}

Lander::~Lander(void)
{
}

void Lander::Draw(void)
{
	const int  num_body_points=7; 
    const int  num_leg_points=4;
    int body_points[num_body_points][2]={{0,20},{5,18},{10,14},{5,5},{-5,5},{-10,14},{-5,18}};
    int leg_points[num_leg_points][2]={{8,9},{15,0},{20,0},{10,0}};
    
    glTranslated(pos.x,pos.y,0);
    glRotated(rotation,0,0,1);
   
    glScaled(2,2,1);
    glTranslated(0,-6,0);
    glBegin(GL_LINE_LOOP);
    for(int i=0;i<num_body_points;i++){
        glVertex2d(body_points[i][0],body_points[i][1]);
    }
    glEnd();


    glBegin(GL_LINES);
    for(int i=0;i<num_leg_points;i++){
        glVertex2d(leg_points[i][0],leg_points[i][1]);
    }
    glEnd();

    glPushMatrix(); 
    glScaled(-1,1,1);
    glBegin(GL_LINES);
    for(int i=0;i<num_leg_points;i++){
        glVertex2d(leg_points[i][0],leg_points[i][1]);
    }
    glEnd();

    glPopMatrix();

    if(flame)DrawFlame();

}

void Lander::DrawFlame(void)
{
    const int  num_flame_points=10;
    int flame_points[num_flame_points][2]={{0,4},{0,-6},{1,3},{4,-4},{-1,3},{-4,-4},{2,2},{6,-3},{-2,2},{-6,-3}};

    glBegin(GL_LINES);
    for(int i=0;i<num_flame_points;i++){
        glVertex2d(flame_points[i][0],flame_points[i][1]);
    }
    glEnd();

}

void Lander::Update(BYTE* keys){

	Vector accel(0,gravity); 

    if(keys['A'] & 128)
        rotation+=rotationSpeed;
    if(keys['S'] & 128)
        rotation-=rotationSpeed;

    if(keys[VK_SPACE]& 128){
        flame=true;
		Vector thrust=engine_acceleration;
		thrust.rotate(-rotation);
        accel.add(thrust);
    }
    else{
        flame=false;
        
    }

    
    vel.add(accel);

    Vector new_pos=pos;
	new_pos.add(vel);
	
	//get the size of the viewport
	GLint p[4];
	glGetIntegerv(GL_VIEWPORT,p);
	int vpwidth=p[2];
	int vpheight=p[3];

	//check for out of bounds
	if(new_pos.x<20)
		vel.x=-vel.x;

	if(new_pos.x>( vpwidth -20))
		vel.x=-vel.x;

	if(new_pos.y < 20){
		vel.y=-vel.y;
		pos.y=20;
	}

	if(new_pos.y > (vpheight-70)){
		vel.y=-vel.y;
		pos.y=vpheight-70-1;
	}
		

	pos.add(vel);

}